@@ -10,6 +10,7 @@ from notecoin.huobi.utils.input_checker import (check_in_list, check_range,
                                                 check_should_not_none,
                                                 check_symbol,
                                                 check_symbol_list)
+from notecoin.huobi.utils.model import Response
 
 
 class MarketClient(object):
@@ -465,7 +466,7 @@ class MarketClient(object):
         channel = "/market/detail/merged"
         return self.market_service.request_process(HttpMethod.GET, channel, params)
 
-    def get_market_tickers(self) -> list:
+    def get_market_tickers(self) -> Response:
         """
         get market tickers
 
