@@ -14,17 +14,15 @@ from notecoin.huobi.utils import *
 from notecoin.huobi.utils.api_signature import create_signature_v2
 from notecoin.huobi.utils.etf_result import etf_result_check
 from notecoin.huobi.utils.huobi_api_exception import HuobiApiException
-from notecoin.huobi.utils.model import Response
+from notecoin.huobi.utils.model import Response, check_response
 from notecoin.huobi.utils.print_mix_object import TypeCheck
 from notecoin.huobi.utils.time_service import get_current_timestamp
 from notecoin.huobi.utils.url_params_builder import UrlParamsBuilder
 
 CONNECT_HEART_BEAT_LIMIT_MS = 60000  # max interval between two package
-# if not need connect immediately, it will enter delay connect status and will connect after setting times
 RECONNECT_AFTER_TIME_MS = 63000
 
 session = requests.Session()
-# Key: original_connection, Value: connection
 websocket_connection_handler = dict()
 connection_id = 0
 
@@ -37,7 +35,7 @@ class ConnectionState:
     CLOSED = 4
 
 
-def check_response(dict_data):
+def check_responses(dict_data):
     status = dict_data.get("status", None)
     code = dict_data.get("code", None)
     success = dict_data.get("success", None)
@@ -56,8 +54,7 @@ def check_response(dict_data):
             if dict_data.get("page") and dict_data.get("components"):
                 pass
             else:
-                raise HuobiApiException(HuobiApiException.EXEC_ERROR,
-                                        "[Executing] System is in maintenances")
+                raise HuobiApiException(HuobiApiException.EXEC_ERROR, "[Executing] System is in maintenances")
     elif code:
         code_int = int(code)
         if code_int != 200:
@@ -79,30 +76,20 @@ def check_response(dict_data):
 
 def call_sync(request, is_checked=False):
     if request.method == "GET":
-        # print("call_sync url : " , request.host + request.url)
         response = session.get(request.host + request.url, headers=request.header)
         if is_checked is True:
             return response.text
-        dict_data = json.loads(response.text, encoding="utf-8")
-        # print("call_sync  === recv data : ", dict_data)
-        check_response(dict_data)
-
-        return Response(dict_data=dict_data)
+        return Response(response=response.text)
 
     elif request.method == "POST":
         response = session.post(request.host + request.url, data=json.dumps(request.post_body), headers=request.header)
-        dict_data = json.loads(response.text, encoding="utf-8")
-        # print("call_sync  === recv data : ", dict_data)
-        check_response(dict_data)
-        return Response(dict_data=dict_data)
+        return Response(response=response.text)
 
 
 def call_sync_perforence_test(request, is_checked=False):
     if request.method == "GET":
         inner_start_time = time.time()
-        # print("call_sync_perforence_test url : ", request.host + request.url)
         response = session.get(request.host + request.url, headers=request.header)
-        # print("call_sync_perforence_test data :", response.text)
         inner_end_time = time.time()
         cost_manual = round(inner_end_time - inner_start_time, 6)
         req_cost = response.elapsed.total_seconds()
