@@ -205,8 +205,7 @@ if __name__ == "__main__":
                               all_periods=['1min'],
                               start_date=datetime(2021, 5, 1),
                               end_date=datetime(2021, 5, 23),
-                              download_dir='/root/workspace/tmp/data'
-                              )
+                              download_dir='/root/workspace/tmp/data')
     history.download_klines()
 
     # download_daily_future()
